### Code linters/formatters
- [ ] PyCharm inspection passed on changed files (or any local IDE)
- [ ] pylint inspection executed and passed on changed files
- [ ] mypy inspection executed and passed on changed files
- [ ] Black code formatter executed and passed on changed files

### Documentation
- [ ] Documentation / README.md has been updated

### Other code changes
- [ ] The soul is pure
